<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../batchprocessing.cpp" line="44"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="45"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Ο ενεργός πυρήνας δεν υποστηρίζει τον επιλεγμένο αλγόριθμο συμπίεσης, παρακαλώ επεξεργαστείτε το αρχείο ρυθμίσεων επιλέγοντας διαφορετικό αλγόριθμο.</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="71"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>Το πρόγραμμα θα σταματήσει και θα ανοίξει το μενού του φορτωτή εκκίνησης με τον επεξεργαστή κειμένου σας.</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="101"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="111"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="114"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>MX Snapshot</source>
        <translation>MX Στιγμιότυπο συστήματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Optional customization</source>
        <translation>Προαιρετική παραμετροποίηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Release version:</source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Boot options:</source>
        <translation>Ρυθμίσεις φορτωτή εκκίνησης:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Live kernel:</source>
        <translation>Ενεργός πυρήνας:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>Project name:</source>
        <translation>Όνομα προϊόντος:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Release date:</source>
        <translation>Ημερομηνία κυκλοφορίας:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>Release codename:</source>
        <translation>Κωδικό όνομα έκδοσης:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Current date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Το στιγμιότυπο συστήματος είναι εργαλείο δημιουργίας εικόνας (ISO) με δυνατότητα εκκίνησης του ενεργού συστήματος σας, την οποία μπορείτε να χρησιμοποιήσετε για αποθήκευση ή διανομή. Κατά τη διάρκεια λειτουργίας του, μπορείτε να συνεχίσετε την εργασία σας με εφαρμογές χωρίς ιδιαίτερες απαιτήσεις.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Χώρος που χρησιμοποιείται για το / (root) και το /home:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Location and ISO name</source>
        <translation>Τοποθεσία και όνομα του ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>Snapshot location:</source>
        <translation>Ο κατάλογος του στιγμιότυπου:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Select a different snapshot directory</source>
        <translation>Επιλογή διαφορετικού καταλόγου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Snapshot name:</source>
        <translation>Το όνομα του στιγμιότυπου:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>Μπορείτε να εξαιρέσετε καταλόγους τσεκάροντας τις πιο κάτω επιλογές, ή κάνοντας κλικ στο κάτω κουμπί για να επεξεργαστείτε άμεσα το /etc/mx-snapshot-exclude.list.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <source>exclude network configurations</source>
        <translation>εξαίρεση της παραμετροποίησης δικτύου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <source>Networks</source>
        <translation>Δίκτυα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>All of the above</source>
        <translation>Όλα τα παραπάνω</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>Desktop</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Documents</source>
        <translation>&apos;Εγγραφα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Type of snapshot:</source>
        <translation>Μορφή στιγμιότυπου:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Διατήρηση λογαριασμών (για τη δημιουργία προσωπικών αντιγράφων ασφαλείας)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;Αυτή η επιλογή.θα επαναφέρει τους κωδικούς &amp;quot;demo&amp;quot; και &amp;quot; root&amp;quot; στις προεπιλογές του MX Linux και δεν θα αντιγράψει προσωπικούς λογαριασμούς.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="542"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Επαναφορά λογαριασμών (για διανομή σε άλλους)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="571"/>
        <source>Edit Exclusion File</source>
        <translation>Επεξεργασία αρχείου εξαιρέσεων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>sha512</source>
        <translation>sha512</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation>Περιορισμός του ρυθμού I/O με το αναφερόμενο ποσοστό.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>I/O throttle:</source>
        <translation>Περιορισμός I/O:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Calculate checksums:</source>
        <translation>Υπολογισμός αθροισμάτων ελέγχου:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>ISO compression scheme:</source>
        <translation>Συμπίεση ISO:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>Number of CPU cores to use:</source>
        <translation>Αριθμός πυρήνων CPU που θα χρησιμοποιηθούν:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>md5</source>
        <translation>md5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Options:</source>
        <translation>Επιλογές:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="823"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="826"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="832"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="848"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="857"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="889"/>
        <source>Next</source>
        <translation>Επόμενο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="936"/>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="952"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="955"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Select Release Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>fastest, worst compression</source>
        <translation>ταχύτατη, χειρότερη συμπίεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>fast, worse compression</source>
        <translation>γρήγορη, χειρότερη συμπίεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>slow, better compression</source>
        <translation>αργή, καλή συμπίεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>best compromise</source>
        <translation>η καλύτερη</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>slowest, best compression</source>
        <translation>πιο αργή, καλύτερη συμπίεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="220"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Ο ελεύθερος χώρος στο %1, όπου τοποθετείται ο φάκελος του στιγμιότυπου: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation>Ο ελεύθερος χώρος θα πρέπει να επαρκεί για να χωρέσει τα συμπιεσμένα δεδομένα από τo / (root) και to /home

      Εάν είναι απαραίτητο, μπορείτε να δημιουργήσετε περισσότερο διαθέσιμο χώρο αφαιρώντας προηγούμενα στιγμιότυπα και αποθηκευμένα αντίγραφα: %1 στιγμιότυπα δεσμεύουν %2 χώρου στο δίσκο.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Installing </source>
        <translation>Εγκατάσταση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Please wait.</source>
        <translation>Παρακαλώ περιμένετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Παρακαλώ περιμένετε. Υπολογισμός χώρου του δίσκου...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="357"/>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Υπάρχει το αρχείο %1. Παρακαλώ χρησιμοποιήστε άλλο όνομα ή διαγράψτε το υπάρχον αρχείο.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Snapshot will use the following settings:</source>
        <translation>Το στιγμιότυπο θα χρησιμοποιήσει τις ακόλουθες ρυθμίσεις:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>- Snapshot directory:</source>
        <translation>- Ο κατάλογος του στιγμιότυπου:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>- Kernel to be used:</source>
        <translation>- Ο πυρήνας που θα χρησιμοποιηθεί:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>NVIDIA Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>NVIDIA Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Ο ενεργός πυρήνας δεν υποστηρίζει τον επιλεγμένο αλγόριθμο συμπίεσης, παρακαλώ επεξεργαστείτε το αρχείο ρυθμίσεων και επιλέξτε διαφορετικό αλγόριθμο.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Final chance</source>
        <translation>Τελευταία ευκαιρία</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Το στιγμιότυπο έχει όλες τις πληροφορίες που χρειάζονται για τη δημιουργία ISO από το ενεργό σύστημα σας.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Θα χρειαστεί κάποιος χρόνος για να ολοκληρωθεί, ανάλογα με το μέγεθος του συστήματος και την ικανότητα του υπολογιστή σας.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>OK to start?</source>
        <translation>Εντάξει για να ξεκινήσει;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Shutdown computer when done.</source>
        <translation>Τερματισμός του υπολογιστή όταν τελειώσει.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Edit Boot Menu</source>
        <translation>Επεξεργασία μενού του φορτωτή εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>Το πρόγραμμα θα σταματήσει τώρα για να σας επιτρέψει να επεξεργαστείτε αρχεία στον κατάλογο εργασίας σας. Επιλέξτε Ναι για να επεξεργαστείτε το μενού του φορτωτή εκκίνησης ή Όχι για να παρακάμψετε αυτό το βήμα και να συνεχίσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>About %1</source>
        <translation>Περί του %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="596"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Πρόγραμμα δημιουργίας live-CD από ενεργό σύστημα του MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="600"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Select Snapshot Directory</source>
        <translation>Επιλογή καταλόγου για το στιγμιότυπο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>Confirmation</source>
        <translation>Επιβεβαίωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Θέλετε σίγουρα να τερματίσετε την εφαρμογή;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>Εργαλείο για τη δημιουργία live-CD από ενεργό σύστημα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Use CLI only</source>
        <translation>Χρήση διεπαφής κειμένου</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Number of CPU cores to be used.</source>
        <translation>Αριθμός πυρήνων CPU που θα χρησιμοποιηθούν.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Output directory</source>
        <translation>Κατάλογος εξόδου</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>Output filename</source>
        <translation>Όνομα αρχείου</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>Δηλώστε διαφορετικό πυρήνα εκτός του προεπιλεγμένου ενεργού, χρησιμοποιώνατς τη μορφή που επιστρέφει η εντολή &apos;uname -r&apos;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Or the full path: %1</source>
        <translation>Ή η ολόκληρη διαδρομή: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Compression level options.</source>
        <translation>Επιλογές επιπέδου συμπίεσης.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation>Χρησιμοποιήστε εισαγωγικά: &quot;-Compression-level &lt;level&gt; &quot;, ή &quot;-Xalgorithm &lt;algorithm&gt; &quot;, ή &quot;-Xhc&quot;, βλέπε man page mksquashfs</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>Δημιουργία μηνιαίου στιγμιότυπου, προσθήκη του ονόματος &apos;Μήνας&apos; στο όνομα του ISO, παράλειψη υπολογισμού του χρησιμοποιημένου χώρου</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>Αυτή η επιλογή επαναφέρει τους λογαριασμούς και τη συμπίεση στις προεπιλογές, οι συνθήκες που αλλάζουν αυτά τα στοιχεία θα αγνοηθούν</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>Χωρίς υπολογισμό αθροισμάτων ελέγχου για το αρχείο ISO που δημιουργείται</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation>Παράλειψη υπολογισμού του ελεύθερου χώρου για το αν χωρά το ISO που προκύπτει</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>Επιλογή για την επίλυση του προβλήματος με τον υπολογισμό αθροισμάτων ελέγχου στα preempt_rt kernels</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Επαναφορά λογαριασμών (για διανομή σε άλλους)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>Υπολογισμός αθροισμάτων ελέγχου για το αρχείο ISO που δημιουργείται</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation>Περιορισμός του ρυθμού I/O με το αναφερόμενο ποσοστό. Αυτό μπορεί να χρησιμοποιηθεί για να μειωθεί η χρήση I/O και CPU του Mksquashfs.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Work directory</source>
        <translation>Κατάλογος εργασίας</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="108"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>Εξαίρεση κύριων φακέλων, έγκυρες επιλογές: </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>Χρησιμοποιήστε την επιλογή για κάθε στοιχείο που θέλετε να εξαιρέσετε</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="113"/>
        <source>Compression format, valid choices: </source>
        <translation>Μορφή συμπίεσης, έγκυρες επιλογές: </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="115"/>
        <source>Shutdown computer when done.</source>
        <translation>Τερματισμός του υπολογιστή όταν τελειώσει.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="144"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Φαίνεται ότι έχετε συνδεθεί ως διαχειριστής, αποσυνδεθείτε και συνδεθείτε ως απλός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="168"/>
        <source>version:</source>
        <translation>έκδοση:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="163"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation>Πρέπει να τρέξετε αυτό το πρόγραμμα με sudo η pkexec.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="139"/>
        <source>MX Snapshot</source>
        <translation>MX Στιγμιότυπο συστήματος</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="148"/>
        <location filename="../main.cpp" line="219"/>
        <location filename="../settings.cpp" line="240"/>
        <location filename="../settings.cpp" line="255"/>
        <location filename="../settings.cpp" line="732"/>
        <location filename="../settings.cpp" line="831"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="216"/>
        <location filename="../settings.cpp" line="249"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>Ο ενεργός πυρήνας δεν υποστηρίζει Squashfs, δεν μπορεί να προχωρήσει.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="85"/>
        <source>Could not create working directory. </source>
        <translation>Δεν κατέστη δυνατή η δημιουργία καταλόγου.εργασίας. </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="109"/>
        <source>Could not create temp directory. </source>
        <translation>Δεν κατέστη δυνατή η δημιουργία προσωρινού καταλόγου. </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="234"/>
        <source>Could not find a usable kernel</source>
        <translation>Δεν κατέστη δυνατή η εύρεση χρήσιμου πυρήνα</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="358"/>
        <source>Used space on / (root): </source>
        <translation>Ο χώρος που χρησιμοποιεί το / (root): </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="361"/>
        <source>estimated</source>
        <translation>κατ&apos; εκτίμηση</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="370"/>
        <source>Used space on /home: </source>
        <translation>Ο χώρος που χρησιμοποιεί το /home: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="458"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Ο ελεύθερος χώρος στο %1, όπου τοποθετείται ο φάκελος του στιγμιότυπου: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="462"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>Ο ελεύθερος χώρος πρέπει να είναι επαρκής για να χωρέσει τα συμπιεσμένα δεδομένα από το / και το /home

      Εάν είναι απαραίτητο, μπορείτε να δημιουργήσετε περισσότερο χώρο
      αφαιρώντας προηγούμενα στιγμιότυπα και αποθηκευμένα αντίγραφα:
      %1 στιγμιότυπα καταλαμβάνουν %2 χώρο στο δίσκο.
</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="480"/>
        <source>Desktop</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="481"/>
        <source>Documents</source>
        <translation>&apos;Εγγραφα</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="482"/>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="483"/>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="484"/>
        <source>Networks</source>
        <translation>Δίκτυα</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="485"/>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="487"/>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="725"/>
        <location filename="../settings.cpp" line="824"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Υπάρχει το αρχείο %1. Παρακαλώ χρησιμοποιήστε άλλο όνομα ή διαγράψτε το υπάρχον αρχείο.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="82"/>
        <source>Cleaning...</source>
        <translation>Εκκαθάριση...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="93"/>
        <location filename="../work.cpp" line="283"/>
        <source>Done</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="105"/>
        <source>Interrupted or failed to complete</source>
        <translation>Σταμάτησε ή απέτυχε να ολοκληρωθεί</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="138"/>
        <location filename="../work.cpp" line="241"/>
        <location filename="../work.cpp" line="263"/>
        <location filename="../work.cpp" line="301"/>
        <location filename="../work.cpp" line="414"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="139"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>Δεν υπάρχει αρκετός ελεύθερος χώρος στο δίσκο προορισμού σας, χρειάζεστε τουλάχιστον %1</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="142"/>
        <source>You have %1 free space on %2</source>
        <translation>Έχετε %1 ελεύθερο χώρο στο %2</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="145"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation>Εάν είστε βέβαιοι ότι έχετε αρκετό ελεύθερο χώρο, εκτελέστε ξανά το πρόγραμμα με την επιλογή -o/--override-size</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="170"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Αντιγραφή του συστήματος αρχείων...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="182"/>
        <source>Could not create temp directory. </source>
        <translation>Δεν κατέστη δυνατή η δημιουργία προσωρινού καταλόγου. </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="238"/>
        <source>Squashing filesystem...</source>
        <translation>Συμπίεση αρχείων...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="242"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation>Δεν κατέστη δυνατή η δημιουργία αρχείου linuxfs, παρακαλώ ελέγξτε /var/log/%1.log</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="260"/>
        <source>Creating CD/DVD image file...</source>
        <translation>Δημιουργία αρχείου εικόνας CD/DVD...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="264"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Δεν κατέστη δυνατή η δημιουργία αρχείου ISO, παρακαλώ ελέγξτε αν έχετε αρκετό χώρο στο προορισμό.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="270"/>
        <source>Making hybrid iso</source>
        <translation>Δημιουργία υβριδικού ISO</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="288"/>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="289"/>
        <source>MX Snapshot completed successfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="290"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>Το στιγμιότυπο χρειάστηκε %1 για να ολοκληρωθεί.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="291"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Ευχαριστούμε που χρησιμοποιήσατε το MX Στιγμιότυπο συστήματος, τρέξτε στη συνέχεια το MX Δημιουργία Live USB!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="298"/>
        <source>Installing </source>
        <translation>Εγκατάσταση </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="301"/>
        <source>Could not install </source>
        <translation>Δεν κατέστη δυνατή η εγκατάσταση </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="311"/>
        <source>Calculating checksum...</source>
        <translation>Υπολογισμός αθροίσματος ελέγχου...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="349"/>
        <source>Building new initrd...</source>
        <translation>Δημιουργία νέου initrd ...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="415"/>
        <source>Could not create working directory. </source>
        <translation>Δεν κατέστη δυνατή η δημιουργία καταλόγου εργασίας. </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="545"/>
        <source>Calculating total size of excluded files...</source>
        <translation>Υπολογισμός συνολικού μεγέθους των εξαιρούμενων αρχείων...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="555"/>
        <source>Calculating size of root...</source>
        <translation>Υπολογισμός μεγέθους root...</translation>
    </message>
</context>
</TS>
